<?php

namespace app\controllers;

use Yii;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\Response;
use yii\filters\VerbFilter;
use app\models\LoginForm;
use app\models\ContactForm;

class SiteController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'only' => ['logout'],
                'rules' => [
                    [
                        'actions' => ['logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
           // 'error' => [
            //    'class' => 'yii\web\ErrorAction',
           // ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }
    
    public function actionError(){
        $errorMsg="ERROR: Invalid endpoint or method. Please try again";
		$token=@Yii::$app->request->headers['token'];
		$class=__FILE__;
		$method=__FUNCTION__;
		$model="API";
		$message= "$errorMsg Please try again";
		Yii::$app->utility->logException($class,$method,$model,$token,$message);
        echo json_encode(array("error" => $errorMsg));
        exit;  
    }

    /**
     * Displays homepage.
     *
     * @return string
     */
    public function actionIndex()
    {
         $params=array();
        
        $API_ARRAY=array();
        $API_ARRAY[]= array('LABEL'=>'Language Info', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','getbysignupuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinlanguageinfo');

        $API_ARRAY[]= array('LABEL'=>'Join Area Master', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinareamaster');

        $API_ARRAY[]= array('LABEL'=>'Join Sign Up', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','login','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinsignup');
                            
        $API_ARRAY[]= array('LABEL'=>'Join OTP', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinotp');
        
        $API_ARRAY[]= array('LABEL'=>'SSO User Token', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/ssousertoken');
         
        $API_ARRAY[]= array('LABEL'=>'Join User Detail', 
                             'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                             'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinuserdetail');
        
        $API_ARRAY[]= array('LABEL'=>'Join Club', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinclub');
                            
        $API_ARRAY[]= array('LABEL'=>'Join Club Activity', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinclubactivity');
                            
        $API_ARRAY[]= array('LABEL'=>'Join Club Activity Mapping', 
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinclubactivitymapping');
                            
        $API_ARRAY[]= array('LABEL'=>'Join User Activity Mapping',
                            'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                            'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinuseractivitymapping');
                            
        $API_ARRAY[]= array('LABEL'=>'Join Club Event', 
                             'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                             'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinclubevent');
                             
        $API_ARRAY[]= array('LABEL'=>'Join Club Event Booking', 
                             'GET_METHODS'=>array('index'),
                            'POST_METHODS'=>array('getbyuuid','create','update','delete' ),
                             'URL'=>'http://demo.jumbolabs.com/join/api/web/index.php/v1/joinclubeventbooking');
      

       
       $params['API_ARRAY']=$API_ARRAY;
        
        return $this->render('index',$params);

    }

    /**
     * Login action.
     *
     * @return Response|string
     */
    public function actionLogin()
    {
        if (!Yii::$app->user->isGuest) {
            return $this->goHome();
        }

        $model = new LoginForm();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {
            return $this->goBack();
        }

        $model->password = '';
        return $this->render('login', [
            'model' => $model,
        ]);
    }

    /**
     * Logout action.
     *
     * @return Response
     */
    public function actionLogout()
    {
        Yii::$app->user->logout();

        return $this->goHome();
    }

    /**
     * Displays contact page.
     *
     * @return Response|string
     */
    public function actionContact()
    {
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post()) && $model->contact(Yii::$app->params['adminEmail'])) {
            Yii::$app->session->setFlash('contactFormSubmitted');

            return $this->refresh();
        }
        return $this->render('contact', [
            'model' => $model,
        ]);
    }

    /**
     * Displays about page.
     *
     * @return string
     */
    public function actionAbout()
    {
        return $this->render('about');
    }
}
