<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "join_club".
 *
 * @property int $join_club_id
 * @property string $join_club_uuid
 * @property string $join_club_name
 * @property string $join_club_rating
 * @property string $join_club_address
 * @property string $join_club_contact_number
 * @property string $join_area_master_uuid
 * @property string $join_club_created_date
 * @property string $join_club_modified_date
 * @property string $join_club_status
 * @property string $join_club_is_deleted
 *
 * @property JoinAreaMaster $joinAreaMasterUu
 * @property JoinClubActivityMapping[] $joinClubActivityMappings
 */
class JoinClub extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'join_club';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['join_club_uuid', 'join_club_name', 'join_club_address', 'join_club_contact_number', 'join_area_master_uuid'], 'required'],
            [['join_club_rating', 'join_club_address', 'join_club_status', 'join_club_is_deleted'], 'string'],
            [['join_club_created_date', 'join_club_modified_date'], 'safe'],
            [['join_club_uuid', 'join_area_master_uuid'], 'string', 'max' => 64],
            [['join_club_name'], 'string', 'max' => 128],
            [['join_club_contact_number'], 'string', 'max' => 16],
            [['join_club_uuid'], 'unique'],
            [['join_area_master_uuid'], 'exist', 'skipOnError' => true, 'targetClass' => JoinAreaMaster::className(), 'targetAttribute' => ['join_area_master_uuid' => 'join_area_master_uuid']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'join_club_id' => Yii::t('app', 'Join Club ID'),
            'join_club_uuid' => Yii::t('app', 'Join Club Uuid'),
            'join_club_name' => Yii::t('app', 'Join Club Name'),
            'join_club_rating' => Yii::t('app', 'Join Club Rating'),
            'join_club_address' => Yii::t('app', 'Join Club Address'),
            'join_club_contact_number' => Yii::t('app', 'Join Club Contact Number'),
            'join_area_master_uuid' => Yii::t('app', 'Join Area Master Uuid'),
            'join_club_created_date' => Yii::t('app', 'Join Club Created Date'),
            'join_club_modified_date' => Yii::t('app', 'Join Club Modified Date'),
            'join_club_status' => Yii::t('app', 'Join Club Status'),
            'join_club_is_deleted' => Yii::t('app', 'Join Club Is Deleted'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinAreaMasterUu()
    {
        return $this->hasOne(JoinAreaMaster::className(), ['join_area_master_uuid' => 'join_area_master_uuid']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinClubActivityMappings()
    {
        return $this->hasMany(JoinClubActivityMapping::className(), ['join_club_uuid' => 'join_club_uuid']);
    }

    /**
     * {@inheritdoc}
     * @return JoinClubQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new JoinClubQuery(get_called_class());
    }
}
