<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "join_club_event".
 *
 * @property int $join_club_event_id
 * @property string $join_club_event_uuid
 * @property string $join_club_event_title
 * @property string $join_club_event_desc
 * @property int $join_club_event_agegroup_from
 * @property int $join_club_event_agegroup_till
 * @property string $join_club_event_area
 * @property string $join_club_activity_uuid
 * @property string $join_club_event_on
 * @property int $join_club_event_number_of_session
 * @property double $join_club_event_cost
 * @property string $join_club_event_banner
 * @property string $join_club_event_created_date
 * @property string $join_club_event_modified_date
 * @property string $join_club_event_status
 * @property string $join_club_event_is_deleted
 *
 * @property JoinAreaMaster $joinClubEventArea
 * @property JoinClubActivity $joinClubActivityUu
 * @property JoinClubEventBooking[] $joinClubEventBookings
 */
class JoinClubEvent extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'join_club_event';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['join_club_event_uuid', 'join_club_event_title', 'join_club_event_desc', 'join_club_event_agegroup_from', 'join_club_event_agegroup_till', 'join_club_event_area', 'join_club_activity_uuid', 'join_club_event_on', 'join_club_event_cost'], 'required'],
            [['join_club_event_desc', 'join_club_event_banner', 'join_club_event_status', 'join_club_event_is_deleted'], 'string'],
            [['join_club_event_agegroup_from', 'join_club_event_agegroup_till', 'join_club_event_number_of_session'], 'integer'],
            [['join_club_event_on', 'join_club_event_created_date', 'join_club_event_modified_date'], 'safe'],
            [['join_club_event_cost'], 'number'],
            [['join_club_event_uuid', 'join_club_event_area', 'join_club_activity_uuid'], 'string', 'max' => 64],
            [['join_club_event_title'], 'string', 'max' => 256],
            [['join_club_event_uuid'], 'unique'],
            [['join_club_event_area'], 'exist', 'skipOnError' => true, 'targetClass' => JoinAreaMaster::className(), 'targetAttribute' => ['join_club_event_area' => 'join_area_master_uuid']],
            [['join_club_activity_uuid'], 'exist', 'skipOnError' => true, 'targetClass' => JoinClubActivity::className(), 'targetAttribute' => ['join_club_activity_uuid' => 'join_club_activity_uuid']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'join_club_event_id' => Yii::t('app', 'Join Club Event ID'),
            'join_club_event_uuid' => Yii::t('app', 'Join Club Event Uuid'),
            'join_club_event_title' => Yii::t('app', 'Join Club Event Title'),
            'join_club_event_desc' => Yii::t('app', 'Join Club Event Desc'),
            'join_club_event_agegroup_from' => Yii::t('app', 'Join Club Event Agegroup From'),
            'join_club_event_agegroup_till' => Yii::t('app', 'Join Club Event Agegroup Till'),
            'join_club_event_area' => Yii::t('app', 'Join Club Event Area'),
            'join_club_activity_uuid' => Yii::t('app', 'Join Club Activity Uuid'),
            'join_club_event_on' => Yii::t('app', 'Join Club Event On'),
            'join_club_event_number_of_session' => Yii::t('app', 'Join Club Event Number Of Session'),
            'join_club_event_cost' => Yii::t('app', 'Join Club Event Cost'),
            'join_club_event_banner' => Yii::t('app', 'Join Club Event Banner'),
            'join_club_event_created_date' => Yii::t('app', 'Join Club Event Created Date'),
            'join_club_event_modified_date' => Yii::t('app', 'Join Club Event Modified Date'),
            'join_club_event_status' => Yii::t('app', 'Join Club Event Status'),
            'join_club_event_is_deleted' => Yii::t('app', 'Join Club Event Is Deleted'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinClubEventArea()
    {
        return $this->hasOne(JoinAreaMaster::className(), ['join_area_master_uuid' => 'join_club_event_area']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinClubActivityUu()
    {
        return $this->hasOne(JoinClubActivity::className(), ['join_club_activity_uuid' => 'join_club_activity_uuid']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinClubEventBookings()
    {
        return $this->hasMany(JoinClubEventBooking::className(), ['join_club_event_uuid' => 'join_club_event_uuid']);
    }

    /**
     * {@inheritdoc}
     * @return JoinClubEventQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new JoinClubEventQuery(get_called_class());
    }
}
