<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "join_signup".
 *
 * @property int $join_signup_id
 * @property string $join_signup_uuid
 * @property string $join_signup_email
 * @property string $join_signup_mobile
 * @property string $join_signup_password
 * @property string $join_signup_password_reset_key
 * @property string $join_area_master_uuid
 * @property string $join_signup_created_date
 * @property string $join_signup_modified_date
 * @property string $join_signup_role
 * @property string $join_signup_status
 * @property string $join_signup_is_deleted
 *
 * @property JoinLanguageInfo[] $joinLanguageInfos
 * @property JoinOtp[] $joinOtps
 * @property JoinAreaMaster $joinAreaMasterUu
 * @property JoinUserActivityMapping[] $joinUserActivityMappings
 * @property JoinUserDetail[] $joinUserDetails
 * @property SsoUserToken $ssoUserToken
 */
class JoinSignup extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'join_signup';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['join_signup_uuid', 'join_signup_email', 'join_signup_mobile', 'join_signup_password', 'join_area_master_uuid'], 'required'],
            [['join_signup_created_date', 'join_signup_modified_date'], 'safe'],
            [['join_signup_role', 'join_signup_status', 'join_signup_is_deleted'], 'string'],
            [['join_signup_uuid', 'join_area_master_uuid'], 'string', 'max' => 64],
            [['join_signup_email', 'join_signup_password'], 'string', 'max' => 128],
            [['join_signup_mobile'], 'string', 'max' => 16],
            [['join_signup_password_reset_key'], 'string', 'max' => 32],
            [['join_signup_uuid'], 'unique'],
            [['join_signup_mobile'], 'unique'],
            [['join_signup_email'], 'unique'],
            [['join_area_master_uuid'], 'exist', 'skipOnError' => true, 'targetClass' => JoinAreaMaster::className(), 'targetAttribute' => ['join_area_master_uuid' => 'join_area_master_uuid']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'join_signup_id' => Yii::t('app', 'Join Signup ID'),
            'join_signup_uuid' => Yii::t('app', 'Join Signup Uuid'),
            'join_signup_email' => Yii::t('app', 'Join Signup Email'),
            'join_signup_mobile' => Yii::t('app', 'Join Signup Mobile'),
            'join_signup_password' => Yii::t('app', 'Join Signup Password'),
            'join_signup_password_reset_key' => Yii::t('app', 'Join Signup Password Reset Key'),
            'join_area_master_uuid' => Yii::t('app', 'Join Area Master Uuid'),
            'join_signup_created_date' => Yii::t('app', 'Join Signup Created Date'),
            'join_signup_modified_date' => Yii::t('app', 'Join Signup Modified Date'),
            'join_signup_role' => Yii::t('app', 'Join Signup Role'),
            'join_signup_status' => Yii::t('app', 'Join Signup Status'),
            'join_signup_is_deleted' => Yii::t('app', 'Join Signup Is Deleted'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinLanguageInfos()
    {
        return $this->hasMany(JoinLanguageInfo::className(), ['join_signup_uuid' => 'join_signup_uuid']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinOtps()
    {
        return $this->hasMany(JoinOtp::className(), ['join_signup_uuid' => 'join_signup_uuid']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinAreaMasterUu()
    {
        return $this->hasOne(JoinAreaMaster::className(), ['join_area_master_uuid' => 'join_area_master_uuid']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinUserActivityMappings()
    {
        return $this->hasMany(JoinUserActivityMapping::className(), ['join_signup_uuid' => 'join_signup_uuid']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getJoinUserDetails()
    {
        return $this->hasMany(JoinUserDetail::className(), ['join_signup_uuid' => 'join_signup_uuid']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getSsoUserToken()
    {
        return $this->hasOne(SsoUserToken::className(), ['user_uuid' => 'join_signup_uuid']);
    }

    /**
     * {@inheritdoc}
     * @return JoinSignupQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new JoinSignupQuery(get_called_class());
    }
}
