<?php

namespace app\modules\admin\controllers;

use Yii;
use app\models\SsoUserInformation;
use app\models\search\ssouserinformationsearch;
use app\models\RbacUser;
use app\models\SsoUserRole;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use app\models\User;
use app\models\WorkflowHistory;
use app\models\ErpMasterGender;
use app\models\ErpMasterCategory;
use app\models\ApplicantInfo;
use yii\helpers\ArrayHelper;

/**
 * ManageusersController implements the CRUD actions for SsoUserInformation model.
 */
class ManageusersController extends Controller
{

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['getcollegelist','index','view','create','createauthuser','delete','update','applicant','updatescholarshipstaus'],
                        'allow' =>  Yii::$app->utility->isSuperAdmin() || Yii::$app->utility->isHelpDeskUser(),
                    ],

                ],
                'denyCallback' => function ($rule, $action) {
                    if (Yii::$app->utility->isSuperAdmin() === false) {
                        return $action->controller->redirect(BASE_URL.'/site/login');
                    }
                    throw new ForbiddenHttpException("Forbidden access");
                }
            ],

        ];
    }


    /**
     * Lists all SsoUserInformation models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new ssouserinformationsearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }


    /**
     * Lists all SsoUserInformation models.
     * @return mixed
     */
    public function actionApplicant()
    {
        $searchModel = new ssouserinformationsearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single SsoUserInformation model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
      if(Yii::$app->utility->isSuperAdmin() === TRUE) {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
      } else {
        $model = $this->findModel($id);
        $registrationNumber = $model->registration_number;
        $applicantmodel = ApplicantInfo::find()
        ->where('applicant_info_registration_number = :applicant_info_registration_number', [':applicant_info_registration_number' => $registrationNumber])
        ->one();
        //echo "<pre>"; print_r($model->attributes); die;
        //$applicantmodel->attributes['aadhar_number'] = $model->attributes['aadhar_number'];
        //echo "<pre>"; print_r($applicantmodel->attributes); die;
        return $this->render('view2', [
            'model' => $model,
            'data' => $applicantmodel
        ]);

      }
    }

    public function actionGetcollegelist(){
      if(isset($_POST['universityuuid'])){
        $uuid = $_POST['universityuuid'];
        $connection = Yii::$app->db;
        $sql = "select college_uuid, collegeid,collegename FROM dhe_legacy_college where affliationid =:id ;
              ";
        $query = $connection->createCommand($sql);
        $query->bindValue(':id', $uuid);
        $model = $query->queryAll();
        echo json_encode($model); die;
      }

    }


    /**
     * Creates a new SsoUserInformation model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreateauthuser()
    {

        $model = new SsoUserInformation();
        if(isset($_POST['SsoUserInformation']['password_hash'])) {
            $moduleName = Ssouserinformation;
            $tableName  = SsoSsouserinformationService;
            $uuid = Yii::$app->utility->generateGuuid($moduleName,$tableName);
            $_POST['SsoUserInformation']['user_uuid'] = $uuid;

            $salt = Yii::$app->utility->generatePasswordSalt();
            $_POST['SsoUserInformation']['user_hkey'] = $salt;
            $passwordHash = hash_hmac('sha1', $_POST['SsoUserInformation']['password_hash'].$salt, PASSWORD_SECRET_KEY);


            $_POST['SsoUserInformation']['password_hash'] = $passwordHash;
            $model->password_hash =  $passwordHash;

            $model->attributes = $_POST['SsoUserInformation'];
            $connection = Yii::$app->db;
            $transaction = $connection->beginTransaction();
            if ($model->validate()) {
              $model->save();
              $res = $this->addUserInRbac($model->attributes);
              if($res == true){
                $params['user_uuid'] = $model->attributes['user_uuid'];

                $roleArray = explode("###",$_POST['SsoUserInformation']['user_role']);
                $roleId = $roleArray[0];
                $roleName = $roleArray[1];
                $userRole[0]['user_uuid'] = $model->attributes['user_uuid'];
                $userRole[0]['role_uuid'] = $roleId;
                $userRole[0]['role_name'] = $roleName;
                $userRole = json_encode($userRole);
                $params['user_role'] = $userRole;
                $userRolePermission['role_permission'] = array();
                $userRolePermission['institute_module_permission'] = array();
                $userRolePermission['user_grant_permission'] = array();
                $userRolePermission['user_denied_permission'] = array();
                //$userRolePermission['college_uuid'] = $_POST['SsoUserInformation']['college'];
                $userRolePermission = json_encode($userRolePermission);
                $params['user_role_permission'] = $userRolePermission;
                $userrole = $this->mapUserRole($params);
                if($userrole == true){
                    $transaction->commit();
                } else {
                  $transaction->rollBack();
                }
              } else{
                $transaction->rollBack();
              }
              return $this->redirect(['view', 'id' => $model->user_id]);
            }else{
              $errors = $model->errors;
              echo "<pre>"; print_r($errors); die;
            }
        }

       //echo "<pre>"; print_r($_POST); die;

        return $this->render('createauthuser', [
            'model' => $model,
        ]);

    }


    // /**
    //  * Updates an existing SsoUserInformation model.
    //  * If update is successful, the browser will be redirected to the 'view' page.
    //  * @param integer $id
    //  * @return mixed
    //  */
    // public function actionUpdateauthuser($id)
    // {
    //     $model = $this->findModel($id);
    //     if(isset($_POST['SsoUserInformation']['password_hash'])) {
    //
    //         $salt = Yii::$app->utility->generatePasswordSalt();
    //         $passwordHash = hash_hmac('sha1', $_POST['SsoUserInformation']['password_hash'].$salt, PASSWORD_SECRET_KEY);
    //
    //
    //         $_POST['SsoUserInformation']['password_hash'] = $passwordHash;
    //         $_POST['SsoUserInformation']['user_hkey'] = $salt;
    //         $model->password_hash =  $passwordHash;
    //         $model->user_hkey =  $salt;
    //     }
    //     if ($model->load($_POST) && $model->save()) {
    //
    //         return $this->redirect(['view', 'id' => $model->user_id]);
    //     } else {
    //       $data = array();
    //       return $this->render('update', [
    //           'model' => $model,
    //           'allpaidselectedinstitutes'=>$allpaidselectedinstitutes
    //       ]);
    //     }
    // }
    //



    /**
     * Creates a new SsoUserInformation model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {

        $model = new SsoUserInformation();
        if(isset($_POST['SsoUserInformation']['password_hash'])) {
            $moduleName = Ssouserinformation;
            $tableName  = SsoSsouserinformationService;
            $uuid = Yii::$app->utility->generateGuuid($moduleName,$tableName);
            $_POST['SsoUserInformation']['user_uuid'] = $uuid;

            $salt = Yii::$app->utility->generatePasswordSalt();
            $_POST['SsoUserInformation']['user_hkey'] = $salt;
            $passwordHash = hash_hmac('sha1', $_POST['SsoUserInformation']['password_hash'].$salt, PASSWORD_SECRET_KEY);


            $_POST['SsoUserInformation']['password_hash'] = $passwordHash;
            $model->password_hash =  $passwordHash;


            $model->attributes = $_POST['SsoUserInformation'];
            $connection = Yii::$app->db;
            $transaction = $connection->beginTransaction();
            if ($model->validate()) {
              $model->save();
              $res = $this->addUserInRbac($model->attributes);
              if($res == true){
                $params['user_uuid'] = $model->attributes['user_uuid'];

                $roleArray = explode("###",$_POST['SsoUserInformation']['user_role']);
                $roleId = $roleArray[0];
                $roleName = $roleArray[1];
                $userRole['user_uuid'] = $model->attributes['user_uuid'];
                $userRole['role_uuid'] = $roleId;
                $userRole['role_name'] = $roleName;
                $userRole = json_encode($userRole);
                $params['user_role'] = $userRole;
                $userRolePermission['role_permission'] = array();
                $userRolePermission['institute_module_permission'] = array();
                $userRolePermission['user_grant_permission'] = array();
                $userRolePermission['user_denied_permission'] = array();
                $userRolePermission['college_uuid'] = $_POST['SsoUserInformation']['college'];
                $userRolePermission = json_encode($userRolePermission);
                $params['user_role_permission'] = $userRolePermission;
                $userrole = $this->mapUserRole($params);
                if($userrole == true){
                    $transaction->commit();
                } else {
                  $transaction->rollBack();
                }
              } else{
                $transaction->rollBack();
              }
              return $this->redirect(['view', 'id' => $model->user_id]);
            }else{
              $errors = $model->errors;
              echo "<pre>"; print_r($errors); die;
            }
        }

       //echo "<pre>"; print_r($_POST); die;

        return $this->render('create', [
            'model' => $model,
        ]);

    }

    /**
     * Updates an existing SsoUserInformation model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id){
   
        $model = $this->findModel($id);
        if(isset($_POST['SsoUserInformation']['password_hash'])) {
                  
            $salt = Yii::$app->utility->generatePasswordSalt();
            $passwordHash = hash_hmac('sha1', $_POST['SsoUserInformation']['password_hash'].$salt, PASSWORD_SECRET_KEY);


            $_POST['SsoUserInformation']['password_hash'] = $passwordHash;
            $_POST['SsoUserInformation']['user_hkey'] = $salt;
            $model->password_hash =  $passwordHash;
            $model->user_hkey =  $salt;
            

        }
      
        if ($model->load($_POST) && $model->save()) { 
       
          if(Yii::$app->utility->isHelpDeskUser() === TRUE){
            $this->updateUserDetail($_POST,$model->attributes['registration_number'],$model->user_id);
          }
          if(Yii::$app->utility->isSuperAdmin() === TRUE) {
            if(isset($_POST['SsoUserInformation']['college'])){
              $user_uuid = $model->attributes['user_uuid'];

              $roleArray = explode("###",$_POST['SsoUserInformation']['user_role']);
              $roleId = $roleArray[0];
              $roleName = $roleArray[1];
              $userRole['user_uuid'] = $model->attributes['user_uuid'];
              $userRole['role_uuid'] = $roleId;
              $userRole['role_name'] = $roleName;
              $userRole = json_encode($userRole);
              //$params['user_role'] = $userRole;
              $userRolePermission['role_permission'] = array();
              $userRolePermission['institute_module_permission'] = array();
              $userRolePermission['user_grant_permission'] = array();
              $userRolePermission['user_denied_permission'] = array();
              $userRolePermission['college_uuid'] = $_POST['SsoUserInformation']['college'];
              $userRolePermission = json_encode($userRolePermission);

              $rmodel = SsoUserRole::find()
              ->where('user_uuid = :user_uuid', [':user_uuid' => $user_uuid])
              ->one();

              $rmodel->user_role_permission = $userRolePermission;
              if ($rmodel->validate()) {
                $rmodel->save();
              }else{
                $errors = $rmodel->errors;
              }
            }
          }
            return $this->redirect(['view', 'id' => $model->user_id]);
        } else {

			
          $roles = array();
          $data = array();
          $allpaidselectedinstitutes = array();
          if(Yii::$app->utility->isHelpDeskUser() === TRUE){
            $registrationNumber = $model->registration_number;
            $connection = Yii::$app->db;
            $sql = "SELECT * FROM applicant_info WHERE applicant_info_registration_number = :applicant_info_registration_number ";
            $query = $connection->createCommand($sql);
            $query->bindValue(':applicant_info_registration_number', $registrationNumber);
            $data = $query->queryOne();

            $applicant_application_uuid = $data['applicant_info_uuid'];

            $sql1 = "SELECT * FROM applicant_profile WHERE applicant_info_uuid = :applicant_info_uuid ";
            $query1 = $connection->createCommand($sql1);
            $query1->bindValue(':applicant_info_uuid', $applicant_application_uuid);
            $GetannualIncome = $query1->queryOne();
           
            $annualIncome = $GetannualIncome['applicant_profile_annual_income'];


            /******************* get income from promoted table for scholasrhip promoted case */ 

            $sql = "select promoted_student_registration_uuid from promoted_students where applicant_info_uuid = '".$applicant_application_uuid."'";
            $query = $connection->createCommand($sql);
            $promoted_student_registration_uuid = $query->queryOne();
            //print_r($promoted_student_registration_uuid); die; 
            $promoted_student_registration_uuid = $promoted_student_registration_uuid['promoted_student_registration_uuid'];

            if($promoted_student_registration_uuid){

             $sqll = "select ps_income from  promoted_student_registration where promoted_student_uuid = '".$promoted_student_registration_uuid."'";
               $queryy = $connection->createCommand($sqll);
               $modell = $queryy->queryOne();
        
              $annualIncome =  ( $modell['ps_income'] ) ? $modell['ps_income'] : 0;
              // echo $annualIncome; die; 


              /*$sql = "select ps_income from  promoted_student_registration where promoted_student_uuid = :promoted_student_uuid";
              $query = $connection->createCommand($sql);
              $query->bindValue(':promoted_student_uuid' , $promoted_student_registration_uuid);
              $model = $query->queryOne();

              $annualIncome =  ( $model['ps_income'] ) ? $model['ps_income'] : 0;*/

            }
            
            /***** ends here ***/

            $allpaidselectedinstitutes = $this->getpaidapplication($applicant_application_uuid);
			$scholarshipdetail = $this->scholarshipdetail($applicant_application_uuid);

			$genderList = ErpMasterGender::find()->where(array(
            "gender_status" => "ACTIVE",
            "gender_is_deleted" => "NO"
            ))->all();
			
			$categoryList = ErpMasterCategory::find()->where(array(
            "category_status" => "ACTIVE",
            "category_is_deleted" => "NO"
            ))->all();
         
          }

          if(Yii::$app->utility->isSuperAdmin() === TRUE){
            $connection = Yii::$app->db;
            $status = 'ACTIVE';
            $sql = "select * FROM sso_role_information WHERE role_status = :status ";
            $query = $connection->createCommand($sql);
            $query->bindValue(':status', $status);
            $roles = $query->queryAll();
          }

            return $this->render('update', [
                'model' => $model,
                'roles' => $roles,
                'data' => $data,
                'allpaidselectedinstitutes'=>$allpaidselectedinstitutes,
				        'scholarshipdetail' => $scholarshipdetail,
                'genderList' => $genderList,
                'categoryList' => $categoryList,
                'annualIncome'=>$annualIncome,
            ]);
        }
    }

    private function getpaidapplication($applicant_application_uuid){

      $application_course_choice_is_deleted="NO";
      $application_course_choice_payment_status = "NOTREQUIRED";
      $application_course_choice_payment_status2 = "SUCCESS";

      $connection = Yii::$app->db;
      $sql = "(SELECT * FROM applicant_application_course_choice WHERE applicant_application_uuid = :applicant_application_uuid AND application_course_choice_is_deleted=:application_course_choice_is_deleted AND (application_course_choice_payment_status = :application_course_choice_payment_status OR application_course_choice_payment_status = :application_course_choice_payment_status2)) ";
      $query = $connection->createCommand($sql);
      $query->bindValue(':application_course_choice_is_deleted', $application_course_choice_is_deleted);
      $query->bindValue(':applicant_application_uuid', $applicant_application_uuid);
      $query->bindValue(':application_course_choice_payment_status', $application_course_choice_payment_status);
      $query->bindValue(':application_course_choice_payment_status2', $application_course_choice_payment_status2);
      $allpaidselectedinstitutes = $query->queryAll();

    //  echo "<pre>"; print_r($allpaidselectedinstitutes); die;
      $kk =0;
      $finalpaiddata = array();
      foreach($allpaidselectedinstitutes as $list){
        //$collegeName = $this->getCollegeName($list['college_uuid']);
        $preferenceData = json_decode($list['application_course_choice_preference'],true);
        //  echo "<pre>"; print_r($preferenceData); exit;
        $courseSectionName = $preferenceData['subjectcombination'][0]['course_section'];
        $collegeName = $preferenceData['subjectcombination'][0]['college'];
        $finalpaiddata[$list['college_uuid']][$collegeName][$kk]['course_name'] = $this->getCourseName($list['college_course_id']); //$list['college_course_id'];
        $finalpaiddata[$list['college_uuid']][$collegeName][$kk]['course_section_name'] = $courseSectionName;
        $finalpaiddata[$list['college_uuid']][$collegeName][$kk]['application_course_choice_uuid'] = $list['application_course_choice_uuid'];
        $finalpaiddata[$list['college_uuid']][$collegeName][$kk]['application_course_choice_preference'] = $list['application_course_choice_preference'];
        $finalpaiddata[$list['college_uuid']][$collegeName][$kk]['application_application_number'] = $list['application_application_number'];
        $finalpaiddata[$list['college_uuid']][$collegeName][$kk]['application_course_choice_payment_status'] = $list['application_course_choice_payment_status'];

        $kk++;
      }
      //echo "<pre>"; print_r($finalpaiddata); exit;
      return $finalpaiddata;
    }
	

	
	private function scholarshipdetail($applicant_application_uuid){
	
      $connection = Yii::$app->db;
      $sql = "select c.scholarship_id,c.scholarship_details_uuid,c.scholarship_details_uuid,c.scholarship_reference_number,c.status from scholarship_details c
                where c.applicant_info_uuid = '".$applicant_application_uuid."'";

      $query = $connection->createCommand($sql);
      $model = $query->queryOne();
      return $model;
	 
	}



   public function actionUpdatescholarshipstaus(){
	
      $connection = Yii::$app->db;
      $sql = "update scholarship_details SET status = '".$_POST['status']."' WHERE scholarship_reference_number = '".$_POST['scholarship_reference_number']."' AND scholarship_id=".$_POST['scholarship_id'];
      $query = $connection->createCommand($sql);

      try {

          $model = $query->execute();

          $workmodel = WorkflowHistory::find()->where(array('application_uuid' => Yii::$app->request->post('scholarship_uuid')))->orderBy(['history_id' => 'DESC'])->one();

          $newmodel = new WorkflowHistory();
          $moduleName = WorkflowHistory;
          $tableName  = WorkflowHistory;
          $uuid= Yii::$app->utility->generateGuuid($moduleName,$tableName);
          $newmodel->history_uuid = $uuid;
          $newmodel->application_uuid = $_POST['scholarship_uuid'];
          $newmodel->forward_by = $workmodel['forward_by'];
          $newmodel->forward_to = $workmodel['forward_to'];
          $newmodel->user_type =  "HELPDESK";
          $newmodel->remarks = "helpdesk";
          $newmodel->status = $_POST['status'];
          $newmodel->application_type = "SCHOLARSHIP";
          $newmodel->user_agent = $_SERVER['HTTP_USER_AGENT'];
          $newmodel->save();

          $sso_uuid = 'helpdesk';
          $table_unique_key = 'UPDATE_APPLICANT_INFO_BY_HELPDESK';
          $role_id = HELPDESK_ROLE_UUID;
          $module_uuid = 'SSO';
          $model_name = 'ScholarshipDetails';
          $new_row = json_encode($_POST);
          $old_row = json_encode($_POST['oldstatus']);
          $token = 'helpdesk';
          $auditlog = Yii::$app->utility->auditlog($sso_uuid,$table_unique_key,$token,$role_id,$module_uuid,$model_name,$new_row,$old_row);

      }
      catch (Exception $ex) {
         echo 'Query failed';
      }  

	}





    private function getCourseName($uuid){
      $connection = Yii::$app->db;
      $sql = "select c.name from dhe_legacy_course c
                inner join dhe_legacy_collegecourse cc on cc.courseid=c.courseid
                where cc.collegecourseid =:id ;
            ";
      $query = $connection->createCommand($sql);
      $query->bindValue(':id', $uuid);
      $model = $query->queryOne();
      return $model['name'];
    }

    private function updateUserDetail($post, $registrationNumber, $user_id){
      // echo "<pre>";print_r($_POST);
      //echo $user_id;
     // die;
        if(isset($_POST['applicant'])) {

           /*** Audit log  Search ****/
            $applicantmodelold = ApplicantInfo::find()
            ->where('applicant_info_registration_number = :applicant_info_registration_number', [':applicant_info_registration_number' => $registrationNumber])->asArray()
            ->one();  
            /*** End Of Audit log ****/

          $applicantmodel = ApplicantInfo::find()
          ->where('applicant_info_registration_number = :applicant_info_registration_number', [':applicant_info_registration_number' => $registrationNumber])
          ->one();
          $applicant_info_uuid = $applicantmodel['applicant_info_uuid'];

          //echo "<pre>"; print_r($applicantmodel->attributes); die;
          $applicantmodel->applicant_info_applicant_name = strtoupper($_POST['SsoUserInformation']['user_name']);
          $applicantmodel->applicant_info_mobile_number =  $_POST['SsoUserInformation']['user_mobile'];
          $applicantmodel->applicant_info_email_id = strtoupper($_POST['SsoUserInformation']['user_email']);
          $applicantmodel->applicant_info_father_name = strtoupper($_POST['applicant']['father_name']);
          $applicantmodel->applicant_info_mother_name = strtoupper($_POST['applicant']['mother_name']);
          $applicantmodel->applicant_info_date_of_birth = $_POST['applicant']['date_of_birth'];
          //$applicantmodel->applicant_profile_annual_income = $_POST['applicant']['applicant_profile_annual_income'];
		      $applicantmodel->gender_uuid = $_POST['applicant']['gender'];
          $applicantmodel->category_uuid = $_POST['applicant']['category'];
          $applicantmodel->applicant_info_haryana_domicile = $_POST['applicant']['applicant_info_haryana_domicile'];
          if($applicantmodel->validate()){
            //$applicantmodel->save();
            if($applicantmodel->save()){
              //   die("ddd");
                $connection = Yii::$app->db;
                $sql = "update applicant_profile set applicant_profile_annual_income ='".$_POST['applicant']['applicant_profile_annual_income']."' where applicant_info_uuid = '".$applicant_info_uuid."'";
                $query = $connection->createCommand($sql);
                $model = $query->execute();

                /***** scholarship detail update ****/
                $sql = "update scholarship_details set annual_income ='".$_POST['applicant']['applicant_profile_annual_income']."' where applicant_info_uuid = '".$applicant_info_uuid."'";
                $query = $connection->createCommand($sql);
                $model = $query->execute();

                 /***** For  Promoted students check ****/
                 $sql = "select promoted_student_registration_uuid from promoted_students where applicant_info_uuid = '".$applicant_info_uuid."'";
                 $query = $connection->createCommand($sql);
                 $promoted_student_registration_uuid = $query->queryOne(); 
                 $promoted_student_registration_uuid = $promoted_student_registration_uuid['promoted_student_registration_uuid'];

                 $sql = "update promoted_student_registration set ps_income ='".$_POST['applicant']['applicant_profile_annual_income']."' where promoted_student_uuid = '".$promoted_student_registration_uuid."'";
                 $query = $connection->createCommand($sql);
                 $model = $query->execute();
                /***** ends here ******/

                /*******   Student iNformation  *****************/
                $user_name = $_POST['SsoUserInformation']['user_name'] ;
                $dob = $_POST['applicant']['date_of_birth'];
                $mobile_number =  $_POST['SsoUserInformation']['user_mobile'];
                $email_id =  strtoupper($_POST['SsoUserInformation']['user_email']);
                $gender_uuid = $_POST['applicant']['gender'];
                $mother_name = strtoupper($_POST['applicant']['mother_name']);
                $category_uuid = $_POST['applicant']['category'];
                $annual_income = $_POST['applicant']['applicant_profile_annual_income'];
                $father_name =  strtoupper($_POST['applicant']['father_name']);

                  $update = "UPDATE student_information SET student_name = '$user_name', dob = '$dob', father_name = '$father_name',
                                 mother_name = '$mother_name', mobile_number = '$mobile_number', email_id = '$email_id', gender = '$gender', gender_uuid = '$gender_uuid', student_category_uuid = '$category_uuid',
                                 annual_income='$annual_income'
                                 WHERE applicant_info_uuid = '$applicant_info_uuid' ";

               
                /***************h  challan table *****************************/
                 
                 $update_hChallan = "UPDATE h_challantable SET StudentName='$user_name',FatherName='$father_name',DOB='$dob',Gender='$gender_uuid',MobileNo='$mobile_number' WHERE Applicant_UUID='$applicant_info_uuid'";

                /*** Audit log ****/
                $applicantmodelnew = ApplicantInfo::find()
                ->where('applicant_info_registration_number = :applicant_info_registration_number', [':applicant_info_registration_number' => $registrationNumber])->asArray()
                ->one(); 
              // echo "<pre>"; print_r(json_encode($applicantmodelnew));die;
                $sso_uuid = $applicantmodel['applicant_info_uuid'];
                $table_unique_key = 'UPDATE_APPLICANT_INFO_BY_HELPDESK';
                $role_id = HELPDESK_ROLE_UUID;
                $module_uuid = 'SSO';
                $model_name = 'updateapplicantdetails';
                $new_row = json_encode($applicantmodelnew);
                $old_row = json_encode($applicantmodelold);
                $token = 'helpdesk';
                $auditlog = Yii::$app->utility->auditlog($sso_uuid,$table_unique_key,$token,$role_id,$module_uuid,$model_name,$new_row,$old_row);
                /*** Ends here  *****/

                return $this->redirect(['view', 'id' => $user_id]);


              }
            //return $this->redirect(['view', 'id' => $user_id]);
          }else{
            $errors = $applicantmodel->getErrors();
            echo "<pre>";print_r($errors);exit;
          }
         
          //return $this->redirect(['view', 'id' => $user_id]);
        }
    }

    private function mapUserRole($params){
      $model = new SsoUserRole();
      $moduleName = Ssouserrolemapin;
      $tableName  = SsouserrolemapinService;
      $uuid = Yii::$app->utility->generateGuuid($moduleName,$tableName);
      $params['user_role_uuid'] = $uuid;
      $model->attributes = $params;
      if ($model->validate()) {
        $model->save();
        return true;
      }else{
        return false;
      }
    }

    private function addUserInRbac($post){
      $model = new RbacUser();
      $params['user_uuid'] = $post['user_uuid'];
      $params['user_name'] = $post['user_name'];
      $model->attributes = $params;
      if ($model->validate()) {
        $model->save();
        return true;
      }else{
        return false;
      }
    }



    /**
     * Deletes an existing SsoUserInformation model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        if(Yii::$app->utility->isHelpDeskUser() === TRUE){
          Yii::$app->session->setFlash('error', "Permission denied",true);
          return $this->redirect(['index']);
        }

        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the SsoUserInformation model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return SsoUserInformation the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = SsoUserInformation::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
