<?php

namespace app\services;

use Yii;
use app\models\SsoUserToken;
use yii\db\Query;



class SsoUserTokenService extends SsoUserToken {

  /**
    *Function to check token is active
    *@param String $token
    *@return Bollean [true false]
    */
    public function isTokenActive($token)
    {
        $token = trim($token);
        $token_status = 'ACTIVE';
        $token_is_deleted = 'NO';
        $query=new Query;
        $query->from('sso_user_token')
            ->where('token=:token AND token_status=:token_status AND token_is_deleted = :token_is_deleted')
            ->addParams([':token' => $token,':token_status'=>$token_status,':token_is_deleted'=>$token_is_deleted])
            ->select("token");
        $command = $query->createCommand();
        $row = $command->queryOne();
        if ($row === false) {
            return false;
        } else {
            $tokenRefreshDate = date('Y-m-d H:i:s');
            Yii::$app->db->createCommand("UPDATE sso_user_token SET token_last_refreshed=:tokenRefreshDate WHERE token=:token")
            ->bindValue(':tokenRefreshDate', $tokenRefreshDate)
            ->bindValue(':token', $token)
            ->execute();
            return true;
        }
    }

    /**
    *Function to delete token is active
    *@param String $token
    *@return Bollean [true false]
    */
    public function deleteToken($token)
    {
    
        $token = trim($token);
        $tokenStatus = 'INACTIVE';
        $tokenIsDeleted = 'YES';
        $tokenRefreshDate = date('Y-m-d H:i:s');
            Yii::$app->db->createCommand("UPDATE sso_user_token SET token_status=:token_status,token_is_deleted=:token_is_deleted WHERE token=:token")
            ->bindValue(':token_status', $tokenStatus)
            ->bindValue(':token_is_deleted', $tokenIsDeleted)
            ->bindValue(':token', $token)
            ->execute();
            
            return true;
    }


  /**
    *Function to get user token by user id
    *@param String $uid
    *@return Bollean [false] OR String token
    */
    public function getTokenByUid($uuid)
    { 
        $token_status = 'ACTIVE';
        $query=new Query;
        $query->from('sso_user_token')
            ->where('user_uuid=:user_uuid AND token_status = :token_status')
            ->addParams([':user_uuid' => $uuid,':token_status'=>$token_status])
            ->select("token");
        $command = $query->createCommand();
        $row = $command->queryOne();
        if ($row === false) {
            return false;
        } else {
            return $row['token'];
        }
    }
    
    /**
    *Function to get user uuid by token
    *@param String $uid
    *@return Bollean [false] OR String token
    */
    public function getUuidByToken($token)
    { 
        $token_status = 'ACTIVE';
        $query=new Query;
        $query->from('sso_user_token')
            ->where('token=:token AND token_status = :token_status')
            ->addParams([':token' => $token,':token_status'=>$token_status])
            ->select("user_uuid");
        $command = $query->createCommand();
        $row = $command->queryOne();
        //echo "<pre>"; print_r($row); die;
        if ($row === false) {
            return false;
        } else {
            return $row['user_uuid'];
        }
    }

    /**
    *Function to save token
    *@param String $uuid
    *@param String $email
    *@return Bollean [false] OR String token
    */
    public function saveUserToken($uuid,$email)
    {
        $expirationDateTime = date('Y-m-d H:i:s', strtotime("+".TOKEN_EXPIRATION_TIME_IN_MINUTS." minutes"));
        $token = Yii::$app->utility->generaterUniqueToken($email);
        if (!empty($token)) {
            $userToken = new SsoUserToken;
            $moduleName = Ssouserinformation;
            $tableName  = SsoUserInformationService;
            $tokenuuid = Yii::$app->utility->generateGuuid($moduleName,$tableName);
            
            $userToken->token_uuid=$tokenuuid;
            $userToken->user_uuid=$uuid;
            $userToken->token=$token;
            $userToken->token_created_date = date('Y-m-d H:i:s');
            $userToken->token_expiration_date = $expirationDateTime;
            $userToken->token_status = 'ACTIVE';
            $userToken->token_is_deleted = 'NO';
            if ($userToken->validate()) {
                $userToken->save();
                return $token;
            } else {
                $errors = $userToken->errors;
                echo "<pre>"; print_r($errors); die;
                return false;                
            }
        } else {
            return false;
        }
    }


}


?>
